const BASE_URL = "https://priority-protection-app.priorityprotection.io";

let cartTotalPrice;
var shop = Shopify.shop;
const cartPrice = document.getElementById("cart-total").value;
var currency = Shopify.currency;
async function getRecurringStatus() {
  const response = await fetch(`${BASE_URL}/getRecurringStatus?shop=${shop}`, {
    method: "GET",
    headers: {
      "Content-Type": "application/json",
    },
  });
  if (!response.ok) {
    throw new Error("Failed to fetch cart");
  }
  const data = await response.json();
  return data;
}
async function getCart() {
  const response = await fetch("/cart.js");
  if (!response.ok) {
    throw new Error("Failed to fetch cart");
  }
  return await response.json();
}
async function updateCartItem(variantId, newQuantity) {
  await fetch(`/cart/change.js`, {
    method: "POST",
    headers: {
      "Content-Type": "application/json",
    },
    body: JSON.stringify({
      id: variantId,
      quantity: newQuantity,
    }),
  });
}
function openPopUp() {
  injectPopup();
  document.querySelector(".modal-overlay").style.display = "block";
  document.querySelector("#popup").style.display = "block";
}
function injectPopup() {
  const parentDocument = window.parent.document;
  const div = parentDocument.createElement("div");
  const popupOverlay = document.getElementsByClassName("modal-overlay")[0];
  const popup = document.getElementById("popup");
  const appendedOverlay = div.appendChild(popupOverlay);
  parentDocument.body.appendChild(appendedOverlay);
  parentDocument.body.appendChild(div);
  parentDocument.body.appendChild(popup);
}
document.addEventListener("DOMContentLoaded", async function () {
  const recurringData = await getRecurringStatus();
  const cart = await getCart();
  const totalPrice = cart.items
    .filter((item) => item.product_title !== "PriorityProtection")
    .reduce((total, item) => total + item.price * item.quantity, 0);
  const cartTotal = totalPrice / 100;
  const priorityVariantPrice = cart.items
    .filter((item) => item.product_title === "PriorityProtection")
    .reduce((total, item) => total + item.price * item.quantity, 0);
  const formattedPriorityVariantPrice = priorityVariantPrice / 100;
  cartTotalPrice = formattedPriorityVariantPrice;
  const hiddenProduct = cart.items.find(
    (item) => item.product_title === "PriorityProtection"
  );
  const totalHeading = Array.from(document.querySelectorAll("*")).find(
    (el) => el.textContent.trim() === cartPrice
  );
  const totalValueElement = totalHeading?.textContent;

  const currencySymbol = totalValueElement?.match(/^\D+/)[0];

  const newPriceValue = new Intl.NumberFormat("en-US", {
    style: "decimal",
    minimumFractionDigits: 2,
    maximumFractionDigits: 2,
  }).format(cartTotal);
  if (totalHeading) {
    totalHeading.innerHTML = `${currencySymbol} ${newPriceValue}`;
  }
  if (recurringData.recurringStatus === "ACTIVE") {
    function isTextWhite(element) {
      // Get the computed color of the text
      const textColor = window.getComputedStyle(element).color;

      // Check if the text color is white
      return (
        textColor === "rgb(255, 255, 255)" ||
        textColor === "#ffffff" ||
        textColor === "rgb(250, 250, 249)" ||
        textColor === "white"
      );
    }

    function PriorityProtection() {
      const newDiv = document.createElement("div");
      const imgPlaceholder = `<img src="${blackLogoImageUrl}" alt="Company Logo" id="priorityProtectionLogo">`;

      newDiv.className = "priorityProtectionContainer";

      newDiv.innerHTML = `
    <div class="priorityProtectionSection">
      <div class="priorityProtectionHead">
        <div class="priorityProtectionLogo">
          ${imgPlaceholder}
          <h5>Priority Protection</h5>
        </div>
        <label class="toggle">
          <input id="toggle-checkbox" type="checkbox" />
          <span class="slider"></span>
        </label>
      </div>
      <h6>Protect all your packages from loss, damage, and theft with streamlined resolutions.
        <a onclick="openPopUp()" href="#">Learn more</a>
        <span id="priorityProtectionCharges">
          ${currency.active} ${cartTotalPrice}
        </span>
        <span id="smallLoader" class="smallLoader-container">
          <span class="smallLoader"></span>
        </span>
        <span id="loader" class="loader-container">
          <span class="loader"></span>
        </span>
      </h6>
    </div>
  `;

      // Function to check surrounding text color and switch logo if needed
      function setLogoBasedOnTextColor() {
        const surroundingTextElement = newDiv.querySelector("h5");
        const imgElementInDOM = newDiv.querySelector("#priorityProtectionLogo");

        if (surroundingTextElement && isTextWhite(surroundingTextElement)) {
          imgElementInDOM.src = whiteLogoImageUrl;
        } else {
          imgElementInDOM.src = blackLogoImageUrl;
        }
        console.log(imgElementInDOM.src, "---src updated");
      }

      const elementsToCheck = [
        { selector: 'main form[action="/cart"]', position: "afterend" },
        { selector: 'a[href="/checkout"]', position: "beforebegin" },
        { selector: "button[name='checkout']", position: "beforebegin" },
        { selector: "input[name='checkout']", position: "beforebegin" },
        { selector: 'form[action="/cart"]', position: "afterend" },
      ];
      function findElementWithText(textPatterns) {
        const elements = document.querySelectorAll("button, a");
        const regex = new RegExp(textPatterns.join("|"), "i");
        for (const element of elements) {
          if (regex.test(element.textContent.trim())) {
            return element;
          }
        }
        return null;
      }
      const textVariations = [
        "Checkout",
        "Check Out",
        "Secure Checkout",
        "Check out",
        "Continue to checkout",
      ];
      const subTotal = document.querySelector(".totals__subtotal-value");
      if (subTotal) {
        console.log(subTotal, "subTotal");
        subTotal.parentNode.insertAdjacentElement("beforebegin", newDiv);
        setLogoBasedOnTextColor();
      } else {
        for (const { selector, position } of elementsToCheck) {
          const cartForm = document.querySelector(selector);
          if (cartForm) {
            if (position === "afterend") {
              console.log(cartForm, "cartForm");
              cartForm.insertAdjacentElement(position, newDiv);
              setLogoBasedOnTextColor();
              break;
            } else if (position === "beforebegin") {
              const beforebeginPos = cartForm.parentNode;
              console.log(beforebeginPos, cartForm, "beforebeginPos");
              beforebeginPos?.parentNode?.insertAdjacentElement(
                "afterbegin",
                newDiv
              );
              setLogoBasedOnTextColor();
              break;
            }
          } else {
            const checkoutButton = findElementWithText(textVariations);
            if (checkoutButton) {
              console.log(checkoutButton, "checkoutButton");
              checkoutButton.parentNode.parentNode.insertAdjacentElement(
                "afterbegin",
                newDiv
              );
              setLogoBasedOnTextColor();
            }
          }
        }
      }
    }

    const element = Array.from(document.querySelectorAll("*")).find(
      (el) => el.textContent.trim() === "PriorityProtection"
    );
    if (element) {
      const parent = element.parentNode.parentNode;
      parent.style.display = "none";
    }
    function closePopUp() {
      document.querySelector(".modal-overlay").style.display = "none";
      document.querySelector("#popup").style.display = "none";
    }
    document
      ?.querySelector(".cross-icon")
      ?.addEventListener("click", function () {
        closePopUp();
      });

    PriorityProtection();
    const priorityProtectionContainer = document.getElementsByClassName(
      "priorityProtectionContainer"
    )[0];
    if (priorityProtectionContainer) {
      if (cart.item_count === 0) {
        priorityProtectionContainer.innerHTML = "";
      }
    }
    const toggleCheckbox = document.getElementById("toggle-checkbox");

    if (toggleCheckbox) {
      const isChecked = localStorage.getItem("isChecked");
      if (isChecked === "true") {
        toggleCheckbox.checked = true;
      } else {
        toggleCheckbox.checked = false;
        const priorityProtectionPrice = document.getElementById(
          "priorityProtectionCharges"
        );
        priorityProtectionPrice.innerHTML = ``;
      }
    }
    const handleToggleChange = async function () {
      if (this.checked) {
        localStorage.setItem("isChecked", "true");
        if (cartTotal <= 100) {
          await removeExistingVariantFromCart();
          await removeVariantFromCart();
          await getVariantToAddToCart(cartTotal);
        } else {
          await removeExistingVariantFromCart();
          await removeVariantFromCart();
          await createVariant();
        }
      } else {
        localStorage.setItem("isChecked", "false");
        await removeExistingVariantFromCart();
        await removeVariantFromCart();
      }
    };
    const attachToggleEventListener = () => {
      const toggleCheckbox = document.getElementById("toggle-checkbox");
      if (toggleCheckbox) {
        toggleCheckbox.removeEventListener("change", handleToggleChange);
        toggleCheckbox.addEventListener("change", handleToggleChange);
      }
    };
    attachToggleEventListener();

    const getVariantToremove = async () => {
      const cartId = await getCart();
      const cartKey = cartId.token.split("key=")[1];
      try {
        const response = await fetch(`${BASE_URL}/getvariantToRemove`, {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            shop: shop,
            cartId: cartKey,
          }),
        });

        const data = await response.json();
        return data;
      } catch (err) {
        console.log(err, "---err");
      }
    };
    async function removeExistingVariantFromCart() {
      const priorityProtectionPrice = document.getElementById(
        "priorityProtectionCharges"
      );
      if (priorityProtectionPrice) {
        priorityProtectionPrice.innerHTML = ``;
      }
      const smallLoader = document.getElementById("smallLoader");
      if (smallLoader) {
        smallLoader.style.display = "flex";
      }
      try {
        const response = await fetch("/cart.js");
        const cart = await response.json();
        const items = cart.items;
        let lineNumber = null;
        items.forEach((item, index) => {
          if (item.product_title === "PriorityProtection") {
            lineNumber = index + 1;
          }
        });

        if (lineNumber) {
          const removeResponse = await fetch("/cart/change.js", {
            method: "POST",
            headers: {
              "Content-Type": "application/json",
            },
            body: JSON.stringify({
              line: lineNumber,
              quantity: 0,
            }),
          });

          const updatedCart = await removeResponse.json();
        } else {
          console.log("Priority Protection not found in the cart.");
        }
      } catch (error) {
        console.error("Error occurred:", error);
      }
    }

    const getVariantToAddToCart = async (cartTotalPrice) => {
      const element1 = Array.from(document.querySelectorAll("*")).find(
        (el) => el.textContent.trim() === "PriorityProtection"
      );
      if (element1) {
        const parent = element1.parentNode.parentNode;
        parent.style.display = "none";
      }
      const priorityProtectionPrice = document.getElementById(
        "priorityProtectionCharges"
      );
      const smallLoader = document.getElementById("smallLoader");
      if (priorityProtectionPrice) priorityProtectionPrice.innerHTML = ``;
      if (smallLoader) smallLoader.style.display = "flex";
      try {
        const response = await fetch(`${BASE_URL}/getVariantToAddToCart`, {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            shop: shop,
            cartPrice: cartTotalPrice,
          }),
        });
        const data = await response.json();
        addVariantToCart(data?.variant[0]?.id);
      } catch (err) {
        console.log(err);
      }
    };
    const createVariant = async () => {
      const element1 = Array.from(document.querySelectorAll("tbody")).find(
        (el) => el.textContent.trim() === "PriorityProtection"
      );
      if (element1) {
        const parent = element1.parentNode.parentNode;
        parent.style.display = "none";
      }
      const priorityProtectionPrice = document.getElementById(
        "priorityProtectionCharges"
      );
      const smallLoader = document.getElementById("smallLoader");
      if (priorityProtectionPrice) priorityProtectionPrice.innerHTML = ``;
      if (smallLoader) smallLoader.style.display = "flex";
      const cart = await getCart();
      const totalPrice = cart.items
        .filter((item) => item.product_title !== "PriorityProtection")
        .reduce((total, item) => total + item.price * item.quantity, 0);
      const cartTotal = totalPrice / 100;
      const cartKey = cart.token.split("key=")[1];
      const fourPercent = cartTotal * 0.04;
      try {
        const response = await fetch(`${BASE_URL}/create-variant`, {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            shop: shop,
            cartKey: cartKey,
            variant: {
              option1: "PriorityProtection" + Date.now(),
              price: fourPercent,
              inventory_policy: "continue",
              metafields: [
                {
                  key: "cart_id",
                  value: cartKey,
                  namespace: "custom",
                  type: "single_line_text_field",
                },
              ],
            },
          }),
        });
        const data = await response.json();

        addVariantToCart(data?.variant?.id);
      } catch (err) {
        console.log(err);
      }
    };
    const addVariantToCart = async (variantId) => {
      const properties = {
        _ishidden: "true",
      };
      try {
        const response = await fetch("/cart/add.js", {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            id: variantId,
            quantity: 1,
            properties,
          }),
        });

        if (!response.ok) {
          throw new Error("Failed to add variant to cart");
        }
        const element1 = Array.from(document.querySelectorAll("*")).find(
          (el) => el.textContent.trim() === "PriorityProtection"
        );
        if (element1) {
          const parent = element1.parentNode.parentNode;
          parent.style.display = "none";
        }
        const cartData = await response.json();
        const priorityProtectionPrice = document.getElementById(
          "priorityProtectionCharges"
        );
        const toggleCheckbox = document.getElementById("toggle-checkbox");

        if (toggleCheckbox) {
          const isChecked = localStorage.getItem("isChecked");
          if (isChecked === "true") {
            toggleCheckbox.checked = true;
          } else {
            toggleCheckbox.checked = false;
          }
        }
        const smallLoader = document.getElementById("smallLoader");
        if (smallLoader) smallLoader.style.display = "none";
        if (priorityProtectionPrice)
          priorityProtectionPrice.innerHTML = `${currencySymbol} ${
            cartData?.price / 100
          }`;
      } catch (error) {
        console.error("Error adding variant to cart:", error);
      }
    };
    async function removeVariantFromCart() {
      const priorityProtectionPrice = document.getElementById(
        "priorityProtectionCharges"
      );
      const smallLoader = document.getElementById("smallLoader");
      if (priorityProtectionPrice) priorityProtectionPrice.innerHTML = ``;
      if (smallLoader) smallLoader.style.display = "flex";
      const element1 = Array.from(document.querySelectorAll("tbody")).find(
        (el) => el.textContent.trim() === "PriorityProtection"
      );
      if (element1) {
        const parent = element1.parentNode.parentNode;
        parent.style.display = "none";
      }
      const variantToRemove = await getVariantToremove();

      if (variantToRemove?.status === 200) {
        const variantId = variantToRemove?.matchingVariant[0]?.id;

        try {
          if (variantId) {
            const response = await fetch("/cart/update.js", {
              method: "POST",
              headers: {
                "Content-Type": "application/json",
              },
              body: JSON.stringify({
                updates: {
                  [variantId]: 0,
                },
              }),
            });
            if (!response.ok) {
              throw new Error("Failed to remove item from cart");
            }
            const data = await response.json();
            smallLoader.style.display = "none";
          } else {
            console.log("Product not found in cart with matching cart_id.");
          }
        } catch (error) {
          console.error("Error:", error);
        }
      }
    }
    if (window.location.pathname === "/cart") {
      const toggleInput = document.getElementById("toggle-checkbox");
      if (toggleInput) {
        const isChecked = localStorage.getItem("isChecked");
        if (isChecked === "true") {
          toggleInput.checked = true;
          if (cartTotal <= 100) {
            await removeExistingVariantFromCart();
            await removeVariantFromCart();           
            await getVariantToAddToCart(cartTotal);
          } else {
            await removeExistingVariantFromCart();
            await removeVariantFromCart();
            await createVariant();
          }
        } else {
          toggleInput.checked = false;
          const priorityProtectionPrice = document.getElementById(
            "priorityProtectionCharges"
          );
          priorityProtectionPrice.innerHTML = ``;
        }
      }
    }

    // cart Events
    (function () {
      if (!window || !window.Shopify) return;

      const CartEvents = {
        add: "SCE:add",
        update: "SCE:update",
        change: "SCE:change",
        clear: "SCE:clear",
        mutate: "SCE:mutate",
      };

      const ShopifyCartURLs = [
        "/cart/add",
        "/cart/update",
        "/cart/change",
        "/cart/clear",
        "/cart/add.js",
        "/cart/update.js",
        "/cart/change.js",
        "/cart/clear.js",
      ];

      function isShopifyCartURL(url) {
        if (!url) return false;
        const path = url.split("/").pop();
        return ShopifyCartURLs.includes(`/cart/${path}`);
      }

      function updateType(url) {
        if (!url) return false;
        if (url.includes("cart/add")) {
          return "add";
        } else if (url.includes("cart/update")) {
          return "update";
        } else if (url.includes("cart/change")) {
          return "change";
        } else if (url.includes("cart/clear")) {
          return "clear";
        } else return false;
      }

      function dispatchEvent(url, detail) {
        if (typeof detail === "string") {
          try {
            detail = JSON.parse(detail);
          } catch {}
        }

        window.dispatchEvent(new CustomEvent(CartEvents.mutate, { detail }));
        const type = updateType(url);
        switch (type) {
          case "add":
            window.dispatchEvent(new CustomEvent(CartEvents.add, { detail }));
            break;
          case "update":
            window.dispatchEvent(
              new CustomEvent(CartEvents.update, { detail })
            );
            break;
          case "change":
            window.dispatchEvent(
              new CustomEvent(CartEvents.change, { detail })
            );
            break;
          case "clear":
            window.dispatchEvent(new CustomEvent(CartEvents.clear, { detail }));
            break;
          default:
            break;
        }
      }

      function XHROverride() {
        if (!window.XMLHttpRequest) return;

        const originalOpen = window.XMLHttpRequest.prototype.open;
        window.XMLHttpRequest.prototype.open = function () {
          const url = arguments[1];
          this.addEventListener("load", function () {
            if (isShopifyCartURL(url)) {
              dispatchEvent(url, this.response);
            }
          });
          return originalOpen.apply(this, arguments);
        };
      }

      function fetchOverride() {
        if (!window.fetch || typeof window.fetch !== "function") return;
        const originalFetch = window.fetch;
        window.fetch = function () {
          const response = originalFetch.apply(this, arguments);

          if (isShopifyCartURL(arguments[0])) {
            response.then((res) => {
              res
                .clone()
                .json()
                .then((data) => dispatchEvent(res.url, data));
            });
          }

          return response;
        };
      }
      fetchOverride();
      XHROverride();
    })();

    window.addEventListener("SCE:change", async (event) => {
      const element2 = Array.from(document.querySelectorAll("*")).find(
        (el) => el.textContent.trim() === "PriorityProtection"
      );
      if (element2) {
        const parent = element2.parentNode.parentNode;
        parent.style.display = "none";
      }
      const cartAfterChange = await getCart();

      const hiddenProduct = cartAfterChange.items.find(
        (item) => item.product_title === "PriorityProtection"
      );

      const itemAdded = event?.detail?.items_added?.some((item) =>
        item.product_title.includes("PriorityProtection")
      );
      const itemRemoved = event.detail?.items_removed?.some((item) =>
        item.product_title.includes("PriorityProtection")
      );
      const cartTotalPriceChange = cartAfterChange.total_price;
      let totalPrice = cartTotalPriceChange / 100;
      const cartPriceChange = cartAfterChange.items
        .filter((item) => item.product_title !== "PriorityProtection")
        .reduce((total, item) => total + item.price * item.quantity, 0);
      const cartTotalChange = cartPriceChange / 100;
      // Format the price with commas and decimals
      let formattedPrice = new Intl.NumberFormat("en-US", {
        style: "decimal",
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
      }).format(totalPrice);
      let priceWithoutDecimals = currencySymbol + formattedPrice.split(".")[0];

      let formattedPricewithSymbol = currencySymbol + formattedPrice;
      let formattedPricewithCurrency = `${formattedPricewithSymbol} ${currency.active}`;

      const totalHeadingChange = Array.from(
        document.querySelectorAll("*")
      ).find(
        (el) =>
          el.textContent.trim() === formattedPricewithCurrency ||
          el.textContent.trim() === formattedPricewithSymbol ||
          el.textContent.trim() === priceWithoutDecimals
      );
      if (totalHeadingChange) {
        const totalValueElement = totalHeadingChange.textContent;

        const currencySymbol = totalValueElement.match(/^\D+/)[0];
        let formattedPriceChange = new Intl.NumberFormat("en-US", {
          style: "decimal",
          minimumFractionDigits: 2,
          maximumFractionDigits: 2,
        }).format(cartTotalChange);

        totalHeadingChange.textContent = `${currencySymbol}${formattedPriceChange}`;
      }
      const toggleInputContainer = document.getElementsByClassName(
        "priorityProtectionContainer"
      )[0];
      if (toggleInputContainer === undefined) {
        PriorityProtection();
      }
      if (toggleInputContainer) {
        if (cartAfterChange.item_count === 0) {
          toggleInputContainer.innerHTML = "";
        }
      }
      if (cartAfterChange.item_count === 1) {
        const product_name = cartAfterChange.items.some(
          (item) => item.product_title === "PriorityProtection"
        );
        if (product_name === true) {
          await removeExistingVariantFromCart();
          await removeVariantFromCart();
        }
      }
      const toggleInputChange = document.getElementById("toggle-checkbox");
      if (toggleInputChange) {
        const isChecked = localStorage.getItem("isChecked");
        if (isChecked === "true") {
          toggleInputChange.checked = true;
        } else {
          toggleInputChange.checked = false;
          const priorityProtectionPrice = document.getElementById(
            "priorityProtectionCharges"
          );
          priorityProtectionPrice.innerHTML = ``;
        }
      }
      if (
        (event?.detail?.items_added?.length == 0 && !itemRemoved) ||
        (event?.detail?.items_removed?.length == 0 && !itemAdded)
      ) {
        if (toggleInputChange || hiddenProduct?.quantity > 1) {
          const isChecked = localStorage.getItem("isChecked");
          if (isChecked === "true") {
            toggleInputChange.checked = true;
            if (cartTotalChange <= 100) {
              await removeExistingVariantFromCart();
              await removeVariantFromCart();
              await getVariantToAddToCart(cartTotalChange);
            } else {
              await removeExistingVariantFromCart();
              await removeVariantFromCart();
              await createVariant();
            }
          } else {
            toggleInputChange.checked = false;
            const priorityProtectionPrice = document.getElementById(
              "priorityProtectionCharges"
            );
            priorityProtectionPrice.innerHTML = ``;
          }
        }
      }
      attachToggleEventListener();
    });
    window.addEventListener("SCE:add", async (event) => {
      const element3 = Array.from(document.querySelectorAll("*")).find(
        (el) => el.textContent.trim() === "PriorityProtection"
      );
      if (element3) {
        const parent = element3.parentNode.parentNode;
        parent.style.display = "none";
      }

      const cartAfterAdd = await getCart();
      const toggleContainer = document.getElementsByClassName(
        "priorityProtectionContainer"
      )[0];
      if (toggleContainer) {
        if (cartAfterAdd.item_count === 0) {
          toggleContainer.innerHTML = "";
        }
      }
      console.log(toggleContainer === undefined, "-------ttt");
      if (
        event.detail.product_title !== "PriorityProtection" &&
        toggleContainer === undefined
      ) {
        PriorityProtection();
      }
      const cartTotalPrice = cartAfterAdd.total_price;
      let totalPrice = cartTotalPrice / 100;
      const cartPriceAdd = cartAfterAdd.items
        .filter((item) => item.product_title !== "PriorityProtection")
        .reduce((total, item) => total + item.price * item.quantity, 0);
      const cartTotalAdd = cartPriceAdd / 100;
      // Format the price with commas and decimals
      let formattedPrice = new Intl.NumberFormat("en-US", {
        style: "decimal",
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
      }).format(totalPrice);
      let formattedPricewithSymbol = currencySymbol + formattedPrice;
      let formattedPricewithCurrency = `${formattedPricewithSymbol} ${currency.active}`;
      let priceWithoutDecimals = currencySymbol + formattedPrice.split(".")[0];
      const totalHeadingAdd = Array.from(document.querySelectorAll("*")).find(
        (el) =>
          el.textContent.trim() === formattedPricewithCurrency ||
          el.textContent.trim() === formattedPricewithSymbol ||
          el.textContent.trim() === priceWithoutDecimals
      );
      if (totalHeadingAdd) {
        const totalValueElement = totalHeadingAdd.textContent;

        const currencySymbol = totalValueElement.match(/^\D+/)[0];
        let formattedPriceChange = new Intl.NumberFormat("en-US", {
          style: "decimal",
          minimumFractionDigits: 2,
          maximumFractionDigits: 2,
        }).format(cartTotalAdd);

        totalHeadingAdd.textContent = `${currencySymbol}${formattedPriceChange}`;
      }

      setTimeout(async () => {
        if (event.detail.product_title !== "PriorityProtection") {
          const toggleInputAdd = document.getElementById("toggle-checkbox");
          if (toggleInputAdd) {
            const isChecked = localStorage.getItem("isChecked");
            if (isChecked === "true") {
              toggleInputAdd.checked = true;
              if (cartTotalAdd <= 100) {
                await removeExistingVariantFromCart();
                await removeVariantFromCart();
                await getVariantToAddToCart(cartTotalAdd);
              } else {
                await removeExistingVariantFromCart();
                await removeVariantFromCart();
                await createVariant();
              }
            } else {
              toggleInputAdd.checked = false;
              const priorityProtectionPrice = document.getElementById(
                "priorityProtectionCharges"
              );
              priorityProtectionPrice.innerHTML = ``;
            }
          }
        }
      }, 100);

      attachToggleEventListener();
    });
  }
});
