import React, { useEffect, useState } from "react";
import { useAuthenticatedFetch } from "../hooks/useAuthenticatedFetch.js";
import {
  Frame,
  Button,
  Page,
  Layout,
  Text,
  InlineStack,
  Card,
  Divider,
  BlockStack,
  List,
} from "@shopify/polaris";

export default function Pricing() {
  const fetch = useAuthenticatedFetch();
  const [loading, setLoading] = useState(false);
  const [recurringStatus, setRecurringStatus] = useState(null);
  const recurringCharge = async () => {
    setLoading(true);
    try {
      const res = await fetch(`/api/recurring`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
      });
      const data = await res.json();
      console.log(data);
      if (data.status === 200 || data.status === 201) {
        top.location.href =
          data?.data?.recurring_application_charge?.confirmation_url;
      } else {
        console.log(res);
      }
      setLoading(false);
    } catch (err) {
      console.log(err);
    }
  };
  const getChargeStatus = async () => {
    try {
      const response = await fetch("/api/getRecurringStatus", {
        method: "GET",
      });
      const data = await response.json();
      setRecurringStatus(data.recurringStatus);
    } catch (err) {
      console.log(err);
    }
  };

  const createProductMyOrder = async () => {
    try {
      const response = await fetch("/api/createProtectMyOrder", {
        method: "GET",
      });
      const data = await response.json();
      console.log(data);
    } catch (err) {
      console.log(err);
    }
  };
  useEffect(() => {
    createProductMyOrder();
    getChargeStatus();
  }, []);

  return (
    <Frame>
      <Page>
        <Layout>
          <Layout.Section>
            <div style={{ margin: "25px 0" }}>
              <Text variant="headingXl" as="h4" alignment="center">
                Pricing
              </Text>
            </div>
            <InlineStack align="center">
              <div style={{ width: "300px" }}>
                <Card>
                  <BlockStack gap={400} align="space-between">
                    <Text variant="headingLg" as="h5" alignment="center">
                      Basic
                    </Text>
                    <Text
                      variant="headingMd"
                      fontWeight="regular"
                      as="h6"
                      alignment="center"
                    >
                      Order Value $40 or under - $1.99
                    </Text>
                    <Text
                      variant="headingMd"
                      fontWeight="regular"
                      as="h6"
                      alignment="center"
                    >
                      Order Value $40 to $50 - $2.49
                    </Text>
                    <Text
                      variant="headingMd"
                      fontWeight="regular"
                      as="h6"
                      alignment="center"
                    >
                      Order Value $50 to $75 - $2.99
                    </Text>
                    <Text
                      variant="headingMd"
                      fontWeight="regular"
                      as="h6"
                      alignment="center"
                    >
                      Order Value $75 to $100 - $4.00
                    </Text>
                    <Text
                      variant="headingMd"
                      fontWeight="regular"
                      as="h6"
                      alignment="center"
                    >
                      Orders Above $100 - 4% of the order value
                    </Text>
                    <div style={{ margin: "3px 0" }}>
                      <Divider />
                    </div>
                    <div style={{ marginBottom: 10 }}>
                      <List>
                        <Text variant="headingMd" as="h6">
                          Guaranteed Safe Delivery
                        </Text>
                        <List.Item>
                          If anything goes wrong with your delivery, you are
                          guaranteed either a reship or a refund
                        </List.Item>
                        <Text variant="headingMd" as="h6">
                          Easy Resolution
                        </Text>
                        <List.Item>
                          Quickly resolve shipping issues with just a few clicks
                        </List.Item>
                      </List>
                    </div>
                    <div style={{ textAlign: "center" }}>
                      <Button
                        loading={loading}
                        variant="primary"
                        className="pricing_button"
                        onClick={recurringCharge}
                      >
                        {recurringStatus === "ACTIVE" ? "Current" : "Upgrade"}
                      </Button>
                    </div>
                  </BlockStack>
                </Card>
              </div>
            </InlineStack>
          </Layout.Section>
        </Layout>
      </Page>
    </Frame>
  );
}
