import React, { useEffect, useState } from "react";
import { useAuthenticatedFetch } from "../hooks/useAuthenticatedFetch.js";
import {
  Frame,
  Button,
  Page,
  Layout,
  Text,
  InlineStack,
  Card,
  Divider,
  Banner,
  Box,
  BlockStack,
  List,
} from "@shopify/polaris";

export default function Installation() {
  const fetch = useAuthenticatedFetch();
  const [appId, setAPPId] = useState(null);
  const [loading, setLoading] = useState(false);
  const [shop, setShop] = useState(null);
  const getAppId = async () => {
    try {
      const response = await fetch("/api/getAppId", {
        method: "GET",
      });
      const data = await response.json();
      setAPPId(data.appId);
      setShop(data.shop);
    } catch (err) {
      console.log(err);
    }
  };
  useEffect(() => {
    getAppId();
  }, []);
  return (
    <Frame>
      <Page title="Installation">
        <Layout>
          <Layout.Section>
            <InlineStack align="center">
              <div style={{ margin: "30px 0", width: "100%" }}>
                <Card>
                  <BlockStack gap={400} align="space-between">
                    <Text variant="headingLg" as="h5" alignment="center">
                      Instructions
                    </Text>
                    <Text variant="headingMd" fontWeight="regular" as="h6">
                      Follow the step by step instructions to get
                      PriorityProtection live on your site
                    </Text>
                    <Text variant="headingSm" as="h6" fontWeight="regular">
                      1. Approve the subscription of the app.
                    </Text>
                    <Text variant="headingSm" as="h6" fontWeight="regular">
                      2. Open the theme editor by clicking on the below button
                    </Text>
                    <Box gap={400} align="space-between">
                      <Button
                        primary
                        url={`https://${shop}/admin/themes/current/editor?context=apps&amp;template=cart&amp;activatedappid=${appId}`}
                      >
                        Open Theme Editor
                      </Button>
                    </Box>
                    <Text variant="headingSm" as="h6" fontWeight="regular">
                      3. Go To App Embeds
                    </Text>
                    <Text variant="headingSm" as="h6" fontWeight="regular">
                      4. Toggle On the Priority Protection
                    </Text>
                    <Text variant="headingSm" as="h6" fontWeight="regular">
                      5. Now, Click on Save Button
                    </Text>

                    <Text variant="headingMd" as="h5">
                      PriorityProtection® is now Set Up on Your Site
                    </Text>
                  </BlockStack>
                  <div style={{ margin: "30px 0", width: "100%" }}>
                    <Banner status="info">
                      <List type="bullet">
                        <List.Item>
                          If in some case Priority Protection is not set up on
                          your site, And if you are familiar with HTML and CSS
                          then you can follow the below step:-
                          <Text>
                            Enter the relevant subtotal element into the{" "}
                            <b>subtotal selector</b> fields. For example, enter
                            .totals__subtotal-value into subtotal selector into
                            drawer , cart etc.
                          </Text>
                        </List.Item>
                        <List.Item>
                          If you are not familiar with HTML and CSS then you can
                          contact on the below email-
                          <Text>info@priorityprotection.io</Text>
                        </List.Item>
                      </List>
                    </Banner>
                  </div>
                </Card>
              </div>
            </InlineStack>
          </Layout.Section>
        </Layout>
      </Page>
    </Frame>
  );
}
